@@ -33,8 +33,6 @@
 #endif
 
 /* AutoInit dependencies.  */
-#include "vtkIOXMLModule.h"
-#include "vtkInfovisLayoutModule.h"
 #include "vtkInteractionStyleModule.h"
 #include "vtkInteractionWidgetsModule.h"
 #include "vtkRenderingCoreModule.h"
