@@ -7,33 +7,37 @@ import vtk.*;
 public class vtkBoxMuellerRandomSequence extends vtkGaussianRandomSequence
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
     { return IsA_1(id0); }
 
-  private native double GetValue_2();
+  private native void Initialize_2(int id0);
+  public void Initialize(int id0)
+    { Initialize_2(id0); }
+
+  private native double GetValue_3();
   public double GetValue()
-    { return GetValue_2(); }
+    { return GetValue_3(); }
 
-  private native void Next_3();
+  private native void Next_4();
   public void Next()
-    { Next_3(); }
+    { Next_4(); }
 
-  private native long GetUniformSequence_4();
+  private native long GetUniformSequence_5();
   public vtkRandomSequence GetUniformSequence() {
-    long temp = GetUniformSequence_4();
+    long temp = GetUniformSequence_5();
 
     if (temp == 0) return null;
     return (vtkRandomSequence)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
-  private native void SetUniformSequence_5(vtkRandomSequence id0);
+  private native void SetUniformSequence_6(vtkRandomSequence id0);
   public void SetUniformSequence(vtkRandomSequence id0)
-    { SetUniformSequence_5(id0); }
+    { SetUniformSequence_6(id0); }
 
   public vtkBoxMuellerRandomSequence() { super(); }
 
