@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkImageOrthoPlanes extends vtkObject
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -25,7 +25,7 @@ public class vtkImageOrthoPlanes extends vtkObject
 
     if (temp == 0) return null;
     return (vtkImagePlaneWidget)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native void ResetPlanes_4();
   public void ResetPlanes()
@@ -37,7 +37,7 @@ public class vtkImageOrthoPlanes extends vtkObject
 
     if (temp == 0) return null;
     return (vtkTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native void HandlePlaneEvent_6(vtkImagePlaneWidget id0);
   public void HandlePlaneEvent(vtkImagePlaneWidget id0)
