@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkTextPropertyCollection extends vtkCollection
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -25,7 +25,7 @@ public class vtkTextPropertyCollection extends vtkCollection
 
     if (temp == 0) return null;
     return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native long GetItem_4(int id0);
   public vtkTextProperty GetItem(int id0) {
@@ -33,7 +33,7 @@ public class vtkTextPropertyCollection extends vtkCollection
 
     if (temp == 0) return null;
     return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native long GetLastItem_5();
   public vtkTextProperty GetLastItem() {
@@ -41,7 +41,7 @@ public class vtkTextPropertyCollection extends vtkCollection
 
     if (temp == 0) return null;
     return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   public vtkTextPropertyCollection() { super(); }
 
