@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkXMLFileReadTester extends vtkXMLParser
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -19,21 +19,13 @@ public class vtkXMLFileReadTester extends vtkXMLParser
   public int TestReadFile()
     { return TestReadFile_2(); }
 
-  private native void SetFileName_3(String id0);
-  public void SetFileName(String id0)
-    { SetFileName_3(id0); }
-
-  private native String GetFileName_4();
-  public String GetFileName()
-    { return GetFileName_4(); }
-
-  private native String GetFileDataType_5();
+  private native String GetFileDataType_3();
   public String GetFileDataType()
-    { return GetFileDataType_5(); }
+    { return GetFileDataType_3(); }
 
-  private native String GetFileVersion_6();
+  private native String GetFileVersion_4();
   public String GetFileVersion()
-    { return GetFileVersion_6(); }
+    { return GetFileVersion_4(); }
 
   public vtkXMLFileReadTester() { super(); }
 
